@@ -13,4 +13,10 @@ connection = connections['mongodb'].connection
 # differently as long as you use get_database()
 def get_database(this_connection=None):
     connection = this_connection and this_connection or connections['mongodb'].connection
-    return connection[settings.DATABASES['mongodb']['NAME']]
\ No newline at end of file
+    return connection[settings.DATABASES['mongodb']['NAME']]
+
+
+def get_version():
+    import os
+    f = os.path.join(os.path.dirname(__file__), 'version.txt')
+    return open(f).read()
\ No newline at end of file
